@@ -12,7 +12,7 @@ require Exporter;
 use strict;
 use vars qw($VERSION @ISA);
 @ISA = qw(Spreadsheet::ParseExcel::Workbook Exporter);
-$VERSION = '0.04'; # 
+$VERSION = '0.06'; # 
 sub new($$) {
     my($sPkg, $oBook) = @_;
     return undef unless(defined $oBook);
@@ -71,6 +71,8 @@ sub SaveAs($$){
 
             $oFmt->set_hidden($rFont->{Hidden});        #Add
 
+            $oFmt->set_locked($pFmt->{Lock});
+
             $oFmt->set_align($aAlH[$pFmt->{AlignH}]);
             $oFmt->set_align($aAlV[$pFmt->{AlignV}]);
             if($pFmt->{Rotate}==0) {
@@ -118,6 +120,15 @@ sub SaveAs($$){
         else {
             $oWrS->set_portrait();
         }
+        #Protect
+        if(defined $oWkS->{Protect}) { # Protect ('':NoPassword, Password:Password)
+	    if ($oWkS->{Protect} ne '') {
+		$oWrS->protect($oWkS->{Protect});
+	    }
+	    else {
+		$oWrS->protect();
+	    }
+        }
         if(($oWkS->{FitWidth}==1) and ($oWkS->{FitHeight}==1)) {
             # Pages on fit with width and Heigt
             $oWrS->fit_to_pages($oWkS->{FitWidth}, $oWkS->{FitHeight});
@@ -187,8 +198,12 @@ sub SaveAs($$){
         for(my $iC = $oWkS->{MinCol} ;
                             defined $oWkS->{MaxCol} && $iC <= $oWkS->{MaxCol} ; $iC++) {            
             if(defined $oWkS->{ColWidth}[$iC]) {
-                $oWrS->set_column($iC, $iC, $oWkS->{ColWidth}[$iC]) ;
-                #$oWrS->set_column($iC, $iC, $oWkS->{ColWidth}[$iC] * MagicCol) ;
+                if($oWkS->{ColWidth}[$iC]>0) {
+                    $oWrS->set_column($iC, $iC, $oWkS->{ColWidth}[$iC]);#, undef, 1) ;
+                }
+                else {
+                    $oWrS->set_column($iC, $iC, 0, undef, 1) ;
+                }
             }
         }
         for(my $iR = $oWkS->{MinRow} ; 
@@ -317,7 +332,7 @@ use vars qw($VERSION @ISA);
 @ISA = qw(Spreadsheet::ParseExcel::Worksheet Exporter);
 sub new($%) {
   my ($sClass, %rhIni) = @_;
-  $sClass->SUPER::new(%rhIni);	# returns object
+  $sClass->SUPER::new(%rhIni);  # returns object
 }
 #------------------------------------------------------------------------------
 # AddCell (for Spreadsheet::ParseExcel::SaveParser::Worksheet)
@@ -326,6 +341,16 @@ sub AddCell($$$$$;$) {
     my($oSelf, $iR, $iC, $sVal, $oCell, $sCode)=@_;
     $oSelf->{_Book}->AddCell($oSelf->{_SheetNo}, $iR, $iC, $sVal, $oCell, $sCode);
 }
+#------------------------------------------------------------------------------
+# Protect (for Spreadsheet::ParseExcel::SaveParser::Worksheet)
+#  - Password = undef   ->  No protect
+#  - Password = ''      ->  Protected. No password
+#  - Password = $pwd    ->  Protected. Password = $pwd
+#------------------------------------------------------------------------------
+sub Protect {
+    my($oSelf, $sPassword)=@_;
+    $oSelf->{Protect} = $sPassword;
+}
 
 #==============================================================================
 # Spreadsheet::ParseExcel::SaveParser
